# Change Log
## [1.2.1 - 2016-05-18]
### Changed
- Hotfix for package installation via PyPI.

## [1.2.0 - 2016-05-18]
### Changed
- Sorted packing to allow upload as package to PyPI.
- Removed dependency on `hgicommon` library (still required for testing though).
- Expanded documentation on how the order of mappings is determined when using mappers and inheritance.
- Changed license from GPL to MIT.

## 1.0.0 - 2016-04-14
### Added
- First stable release.
